@@ -82,6 +82,13 @@ const (
 	LinkDisableDWARF
 )
 
+// TempFile makes a (good enough) random temporary file name
+func TempFile(name string) string {
+	r := make([]byte, 4)
+	rand.Read(r)
+	return filepath.Join(os.TempDir(), fmt.Sprintf("%s.%s", name, hex.EncodeToString(r)))
+}
+
 // BuildFixture will compile the fixture 'name' using the provided build flags.
 func BuildFixture(name string, flags BuildFlags) Fixture {
 	if !runningWithFixtures {
@@ -93,14 +100,13 @@ func BuildFixture(name string, flags BuildFlags) Fixture {
 	}
 
 	if flags&EnableCGOOptimization == 0 {
-		os.Setenv("CGO_CFLAGS", "-O0 -g")
+		if os.Getenv("CI") == "" || os.Getenv("CGO_CFLAGS") == "" {
+			os.Setenv("CGO_CFLAGS", "-O0 -g")
+		}
 	}
 
 	fixturesDir := FindFixturesDir()
 
-	// Make a (good enough) random temporary file name
-	r := make([]byte, 4)
-	rand.Read(r)
 	dir := fixturesDir
 	path := filepath.Join(fixturesDir, name+".go")
 	if name[len(name)-1] == '/' {
@@ -108,7 +114,7 @@ func BuildFixture(name string, flags BuildFlags) Fixture {
 		path = ""
 		name = name[:len(name)-1]
 	}
-	tmpfile := filepath.Join(os.TempDir(), fmt.Sprintf("%s.%s", name, hex.EncodeToString(r)))
+	tmpfile := TempFile(name)
 
 	buildFlags := []string{"build"}
 	var ver goversion.GoVersion
@@ -163,6 +169,9 @@ func BuildFixture(name string, flags BuildFlags) Fixture {
 
 	cmd := exec.Command("go", buildFlags...)
 	cmd.Dir = dir
+	if os.Getenv("CI") != "" {
+		cmd.Env = os.Environ()
+	}
 
 	// Build the test binary
 	if out, err := cmd.CombinedOutput(); err != nil {
@@ -186,7 +195,7 @@ func BuildFixture(name string, flags BuildFlags) Fixture {
 	source = filepath.ToSlash(source)
 	sympath, err := filepath.EvalSymlinks(source)
 	if err == nil {
-		source = strings.Replace(sympath, "\\", "/", -1)
+		source = strings.ReplaceAll(sympath, "\\", "/")
 	}
 
 	absdir, _ := filepath.Abs(dir)
@@ -228,34 +237,12 @@ func RunTestsWithFixtures(m *testing.M) int {
 var recordingAllowed = map[string]bool{}
 var recordingAllowedMu sync.Mutex
 
-// testName returns the name of the test being run using runtime.Caller.
-// On go1.8 t.Name() could be called instead, this is a workaround to
-// support <=go1.7
-func testName(t testing.TB) string {
-	for i := 1; i < 10; i++ {
-		pc, _, _, ok := runtime.Caller(i)
-		if !ok {
-			break
-		}
-		fn := runtime.FuncForPC(pc)
-		if fn == nil {
-			continue
-		}
-		name := fn.Name()
-		v := strings.Split(name, ".")
-		if strings.HasPrefix(v[len(v)-1], "Test") {
-			return name
-		}
-	}
-	return "unknown"
-}
-
 // AllowRecording allows the calling test to be used with a recording of the
 // fixture.
 func AllowRecording(t testing.TB) {
 	recordingAllowedMu.Lock()
 	defer recordingAllowedMu.Unlock()
-	name := testName(t)
+	name := t.Name()
 	t.Logf("enabling recording for %s", name)
 	recordingAllowed[name] = true
 }
@@ -283,7 +270,7 @@ func AllowRecording(t testing.TB) {
 func MustHaveRecordingAllowed(t testing.TB) {
 	recordingAllowedMu.Lock()
 	defer recordingAllowedMu.Unlock()
-	name := testName(t)
+	name := t.Name()
 	if !recordingAllowed[name] {
 		t.Skipf("recording not allowed for %s", name)
 	}
@@ -292,12 +279,7 @@ func MustHaveRecordingAllowed(t testing.TB) {
 // SafeRemoveAll removes dir and its contents but only as long as dir does
 // not contain directories.
 func SafeRemoveAll(dir string) {
-	dh, err := os.Open(dir)
-	if err != nil {
-		return
-	}
-	defer dh.Close()
-	fis, err := dh.Readdir(-1)
+	fis, err := os.ReadDir(dir)
 	if err != nil {
 		return
 	}
@@ -325,17 +307,20 @@ func MustSupportFunctionCalls(t *testing.T, testBackend string) {
 		t.Skip("this backend does not support function calls")
 	}
 
-	if runtime.GOOS == "darwin" && os.Getenv("TRAVIS") == "true" && runtime.GOARCH == "amd64" {
-		t.Skip("function call injection tests are failing on macOS on Travis-CI (see #1802)")
-	}
 	if runtime.GOARCH == "386" {
 		t.Skip(fmt.Errorf("%s does not support FunctionCall for now", runtime.GOARCH))
 	}
 	if runtime.GOARCH == "arm64" {
-		if !goversion.VersionAfterOrEqual(runtime.Version(), 1, 19) {
+		if !goversion.VersionAfterOrEqual(runtime.Version(), 1, 19) || runtime.GOOS == "windows" {
 			t.Skip("this version of Go does not support function calls")
 		}
 	}
+
+	if runtime.GOARCH == "ppc64le" {
+		if !goversion.VersionAfterOrEqual(runtime.Version(), 1, 22) {
+			t.Skip("On PPC64LE Building with Go lesser than 1.22 does not support function calls")
+		}
+	}
 }
 
 // DefaultTestBackend changes the value of testBackend to be the default
@@ -382,8 +367,9 @@ var hasCgo = func() bool {
 	if strings.TrimSpace(string(out)) != "1" {
 		return false
 	}
-	_, err = exec.LookPath("gcc")
-	return err == nil
+	_, err1 := exec.LookPath("gcc")
+	_, err2 := exec.LookPath("clang")
+	return (err1 == nil) || (err2 == nil)
 }()
 
 func MustHaveCgo(t *testing.T) {
